@@ -72,7 +72,6 @@ import Swish.Utils.ListHelpers (flist)
 -- import Swish.Utils.ShowM (ShowM(..))
 
 import Control.Applicative ((<$>))
-import Control.Monad (join)
 
 import Data.Maybe (isJust, catMaybes)
 
@@ -253,7 +252,7 @@ tvalMkCanonicalForm dtv str = can
     where
       dtmap = tvalMap dtv
       val   = mapL2V dtmap str
-      can   = join $ fmap (mapV2L dtmap) val
+      can   = mapV2L dtmap =<< val
 
 -- |DatatypeMap consists of methods that perform lexical-to-value
 --  and value-to-canonical-lexical mappings for a datatype.
