@@ -74,7 +74,10 @@ import Data.Monoid (Monoid(..))
 
 import Network.URI (URI, parseURI)
 
-#if MIN_VERSION_time(1,5,0)
+#if MIN_VERSION_time(1,9,0)
+import Data.Time (UTCTime(..), Day, fromGregorian, defaultTimeLocale)
+import Data.Time.Format.Internal (buildTime)
+#elif MIN_VERSION_time(1,5,0)
 import Data.Time (UTCTime(..), Day, fromGregorian, buildTime, defaultTimeLocale)
 #else
 import Data.Time (UTCTime(..), Day, fromGregorian, buildTime)
