@@ -5,7 +5,7 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  TurtleTest
---  Copyright   :  (c) 2013 Douglas Burke
+--  Copyright   :  (c) 2013, 2018 Douglas Burke
 --  License     :  GPL V2
 -- 
 --  Maintainer  :  Douglas Burke
@@ -374,7 +374,7 @@ result2_7_a =
      ]
 
 {-
-### Failure in: 0:6:1:"example: 2.7 a"
+--- Failure in: 0:6:1:"example: 2.7 a"
 expected: Graph, formulae:
 arcs:
     (_:23,foaf:name,"Bob")
